==> openshift-model-console-5.0.2-sources.jar: annotations/io/fabric8/openshift/api/model/console/v1/CLIDownloadLinkBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CLIDownloadLinkBuilder extends CLIDownloadLinkFluentImpl<CLIDownloadLinkBuilder> implements VisitableBuilder<CLIDownloadLink,CLIDownloadLinkBuilder> {

    CLIDownloadLinkFluent<?> fluent;
    Boolean validationEnabled;

    public CLIDownloadLinkBuilder() {
        this(true);
    }

    public CLIDownloadLinkBuilder(Boolean validationEnabled) {
        this(new CLIDownloadLink(), validationEnabled);
    }

    public CLIDownloadLinkBuilder(CLIDownloadLinkFluent<?> fluent) {
        this(fluent, true);
    }

    public CLIDownloadLinkBuilder(CLIDownloadLinkFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new CLIDownloadLink(), validationEnabled);
    }

    public CLIDownloadLinkBuilder(CLIDownloadLinkFluent<?> fluent,CLIDownloadLink instance) {
        this(fluent, instance, true);
    }

    public CLIDownloadLinkBuilder(CLIDownloadLinkFluent<?> fluent,CLIDownloadLink instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withHref(instance.getHref()); 
        fluent.withText(instance.getText()); 
        this.validationEnabled = validationEnabled; 
    }

    public CLIDownloadLinkBuilder(CLIDownloadLink instance) {
        this(instance,true);
    }

    public CLIDownloadLinkBuilder(CLIDownloadLink instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withHref(instance.getHref()); 
        this.withText(instance.getText()); 
        this.validationEnabled = validationEnabled; 
    }

    public CLIDownloadLink build() {
        CLIDownloadLink buildable = new CLIDownloadLink(fluent.getHref(),fluent.getText());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CLIDownloadLinkBuilder that = (CLIDownloadLinkBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> openshift-model-console-5.3.1-sources.jar: annotations/io/fabric8/openshift/api/model/console/v1/CLIDownloadLinkBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CLIDownloadLinkBuilder extends CLIDownloadLinkFluentImpl<CLIDownloadLinkBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<CLIDownloadLink,CLIDownloadLinkBuilder> {

    CLIDownloadLinkFluent<?> fluent;
    Boolean validationEnabled;

    public CLIDownloadLinkBuilder() {
        this(true);
    }

    public CLIDownloadLinkBuilder(Boolean validationEnabled) {
        this(new CLIDownloadLink(), validationEnabled);
    }

    public CLIDownloadLinkBuilder(CLIDownloadLinkFluent<?> fluent) {
        this(fluent, true);
    }

    public CLIDownloadLinkBuilder(CLIDownloadLinkFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new CLIDownloadLink(), validationEnabled);
    }

    public CLIDownloadLinkBuilder(CLIDownloadLinkFluent<?> fluent,CLIDownloadLink instance) {
        this(fluent, instance, true);
    }

    public CLIDownloadLinkBuilder(CLIDownloadLinkFluent<?> fluent,CLIDownloadLink instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withHref(instance.getHref()); 
        fluent.withText(instance.getText()); 
        this.validationEnabled = validationEnabled; 
    }

    public CLIDownloadLinkBuilder(CLIDownloadLink instance) {
        this(instance,true);
    }

    public CLIDownloadLinkBuilder(CLIDownloadLink instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withHref(instance.getHref()); 
        this.withText(instance.getText()); 
        this.validationEnabled = validationEnabled; 
    }

    public CLIDownloadLink build() {
        CLIDownloadLink buildable = new CLIDownloadLink(fluent.getHref(),fluent.getText());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CLIDownloadLinkBuilder that = (CLIDownloadLinkBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
